"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyvAdapter = void 0;
const keyv_1 = __importDefault(require("keyv"));
const dataloader_1 = __importDefault(require("dataloader"));
class KeyvAdapter {
    constructor(keyv, options) {
        this.keyv = keyv ?? new keyv_1.default();
        this.dataLoader = options?.disableBatchReads
            ? undefined
            : new dataloader_1.default(async (keys) => {
                const result = await this.keyv.get([...keys]);
                if (!result) {
                    return [...Array(keys.length)];
                }
                return result;
            }, { cache: false });
    }
    async get(key) {
        return this.dataLoader ? this.dataLoader.load(key) : this.keyv.get(key);
    }
    async set(key, value, opts) {
        if (typeof opts?.ttl === "number" && !Number.isNaN(opts.ttl)) {
            await this.keyv.set(key, value, opts.ttl * 1000);
        }
        else {
            await this.keyv.set(key, value);
        }
    }
    async delete(key) {
        return this.keyv.delete(key);
    }
}
exports.KeyvAdapter = KeyvAdapter;
//# sourceMappingURL=index.js.map